summaryrefslogtreecommitdiffstats
path: root/kshowmail/showrecordelem.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-07-24 15:59:03 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-07-24 15:59:03 -0500
commit9c02dbb59ce57c68dc177d9294b980bf114a3e11 (patch)
treeb1b40423c9be9a42a97cd0e8f3af3139aefb6fa0 /kshowmail/showrecordelem.h
parent0b875800e452c97b1a3f25aba5f029a8c33a4b93 (diff)
downloadkshowmail-9c02dbb59ce57c68dc177d9294b980bf114a3e11.tar.gz
kshowmail-9c02dbb59ce57c68dc177d9294b980bf114a3e11.zip
Update to TDE R14 API
Diffstat (limited to 'kshowmail/showrecordelem.h')
-rw-r--r--kshowmail/showrecordelem.h92
1 files changed, 46 insertions, 46 deletions
diff --git a/kshowmail/showrecordelem.h b/kshowmail/showrecordelem.h
index 3d5e9f6..e14ef3f 100644
--- a/kshowmail/showrecordelem.h
+++ b/kshowmail/showrecordelem.h
@@ -18,15 +18,15 @@
#ifndef SHOWRECORDELEM_H
#define SHOWRECORDELEM_H
-//Qt headers
-#include <qdom.h>
-#include <qstring.h>
-#include <qlistview.h>
-#include <qdatetime.h>
+//TQt headers
+#include <ntqdom.h>
+#include <ntqstring.h>
+#include <ntqlistview.h>
+#include <ntqdatetime.h>
//KDE headers
-#include <klocale.h>
-#include <kglobal.h>
+#include <tdelocale.h>
+#include <tdeglobal.h>
#include <kdebug.h>
#include <mimelib/datetime.h>
#include <kmdcodec.h>
@@ -86,44 +86,44 @@ class ShowRecordElem
* @param uid Unique ID of the mail
* @param isNew TRUE - mail is new; FALSE - mail is not new
*/
- ShowRecordElem( int number, QString& uid, bool isNew );
+ ShowRecordElem( int number, TQString& uid, bool isNew );
/**
* Sets the mail header and extracts From, To, Subject, Date and Content Type.
* All parts of the header are coded according RFC 2047.
* @param header the mail header
*/
- void setHeader( const QString& header );
+ void setHeader( const TQString& header );
/**
* Returns the whole header.
* @return the mail header
*/
- QString header() const;
+ TQString header() const;
/**
* Returns the sender address.
* @return sender address
*/
- QString from() const;
+ TQString from() const;
/**
* Returns the addressee.
* @return the addressee
*/
- QString to() const;
+ TQString to() const;
/**
* Returns the subject.
* @return mail subject
*/
- QString subject() const;
+ TQString subject() const;
/**
* Returns the stored content type.
* @return content type
*/
- QString content() const;
+ TQString content() const;
/**
@@ -131,7 +131,7 @@ class ShowRecordElem
* locale's conventions.
* @return the date
*/
- QString date() const;
+ TQString date() const;
/**
* Returns the date on which the mail was sent.
@@ -139,25 +139,25 @@ class ShowRecordElem
* representations of dates and times, which is YYYY-MM-DDTHH:MM:SS
* @return the date
*/
- QString strUnixTime () const;
+ TQString strUnixTime () const;
/**
* Returns the date and time on which the mail was sent.
* @return the date
*/
- QDateTime sentDateTime() const;
+ TQDateTime sentDateTime() const;
/**
* Sets the unique mail ID.
* @param uid the ID
*/
- void setUIDL( const QString& uid );
+ void setUIDL( const TQString& uid );
/**
* Returns the unique ID of this mail.
* @return UID
*/
- QString uidl() const;
+ TQString uidl() const;
/**
* Sets the size of the mail.
@@ -175,12 +175,12 @@ class ShowRecordElem
* Returns the mail size as string.
* The String has a length of 8 and the number is right-aligned to allow sorting.
*/
- QString strSize () const;
+ TQString strSize () const;
/**
* Returns the mails size as string with prefix
*/
- QString strSizePrefix() const;
+ TQString strSizePrefix() const;
/**
* Sets whether the mail is new or not.
@@ -200,7 +200,7 @@ class ShowRecordElem
* @return localized String "new", if the mail is new
* @return localized String "old", if the mail is not new
*/
- QString state() const;
+ TQString state() const;
/**
* Sets the number of this mail.
@@ -236,14 +236,14 @@ class ShowRecordElem
* at the next view refresh.
* @param filter pointer to the header filter
* @param account name of the account
* @param mailbox reference to a QString object in which the mailbox name shall be written if the action is MOVE
* @param log pointer to the filter log
* @return recommend action
* @see FilterAction_Type
* @see HeaderFilter
* @see markAtViewRefresh
*/
- FilterAction_Type applyHeaderFilter( HeaderFilter* filter, QString account, QString& mailbox, FilterLog* log = NULL );
+ FilterAction_Type applyHeaderFilter( HeaderFilter* filter, TQString account, TQString& mailbox, FilterLog* log = NULL );
/**
* Read a mail (header, size, uid and number) from the given DOM element
@@ -252,7 +252,7 @@ class ShowRecordElem
* a child node called "header".
* @param elem a DOM element which contains a mail
*/
- void readOptions( QDomElement& elem );
+ void readOptions( TQDomElement& elem );
/**
* Creates a new DOM element in the given DOM document and add it to given
@@ -260,7 +260,7 @@ class ShowRecordElem
* @param doc the DOM document in that all options are stored
* @param parent the parent element (account) of the mail
*/
- void saveOptions( QDomDocument& doc, QDomElement& parent );
+ void saveOptions( TQDomDocument& doc, TQDomElement& parent );
/**
* Returns whether the mail is selected in the list view.
@@ -280,7 +280,7 @@ class ShowRecordElem
* @param preferHTML decode HTML part if present
* @return decoded mail body
*/
- QString decodeMailBody( QByteArray body, bool preferHTML ) const;
+ TQString decodeMailBody( TQByteArray body, bool preferHTML ) const;
/**
* Shows the header in a dialog box.
@@ -288,7 +288,7 @@ class ShowRecordElem
* @return continueShowHeaders - the user has OK clicked. The invoking function will show the next header
* @return cancelShowHeaders - the user has Cancel clicked. The invoking function will not show the next header.
*/
- int showHeader( QString& account );
+ int showHeader( TQString& account );
/**
* Writes this mail into the Move Log.
@@ -296,14 +296,14 @@ class ShowRecordElem
* @param account name of the account
* @param mailbox name of the mailbox
*/
- void writeToMoveLog( FilterLog* log, QString account, QString mailbox );
+ void writeToMoveLog( FilterLog* log, TQString account, TQString mailbox );
/**
* Writes this mail into the Delete Log.
* @param log pointer to the log
* @param account name of the account
*/
- void writeToDeleteLog( FilterLog* log, QString account );
+ void writeToDeleteLog( FilterLog* log, TQString account );
/**
* The mail will be marked at the next view refresh.
@@ -315,37 +315,37 @@ class ShowRecordElem
/**
* Mail header; coded according RFC 2047
*/
- QCString m_header;
+ TQCString m_header;
/**
* The sender address; coded according RFC 2047
*/
- QCString m_from;
+ TQCString m_from;
/**
* The addressee; coded according RFC 2047
*/
- QCString m_to;
+ TQCString m_to;
/**
* The subject; coded according RFC 2047
*/
- QCString m_subject;
+ TQCString m_subject;
/**
* The date on which the mail was sent
*/
- QDateTime m_unixDate;
+ TQDateTime m_unixDate;
/**
* The content type
*/
- QCString m_content;
+ TQCString m_content;
/**
* The unique ID of the mail.
*/
- QString m_uid;
+ TQString m_uid;
/**
* Size of the mail
@@ -388,51 +388,51 @@ class ShowRecordElem
* @param item the search item
* @return the content of the found line
*/
- QCString scanHeader( const QString& item ) const;
+ TQCString scanHeader( const TQString& item ) const;
/**
* Sets the given string as sender address
* @param from sender address
*/
- void setFrom( const QCString& from );
+ void setFrom( const TQCString& from );
/**
* Sets the given string as recipient address
* @param to recipient address
*/
- void setTo( const QCString& to );
+ void setTo( const TQCString& to );
/**
* Sets the given string as subject
* @param subject the mail subject
*/
- void setSubject( const QCString& subject );
+ void setSubject( const TQCString& subject );
/**
* Converts the given string to a date-time value and stores it.
* @param date the date
*/
- void setDate( const QCString& date );
+ void setDate( const TQCString& date );
/**
* Sets the given string as content type.
* @param content the content type
*/
- void setContent( const QCString& content );
+ void setContent( const TQCString& content );
/**
* Returns the boundary, if the mail has a multi part body.
* Otherwise it returns an empty string.
* @return boundary
*/
- QString getBoundary() const;
+ TQString getBoundary() const;
/**
* Returns the char set of the content (e.g. iso-8859-1).
* If no char set is denoted, it will returns an empty string.
* @return charset
*/
- QString getCharset() const;
+ TQString getCharset() const;
/**
* Returns the content transfer encoding of the content
@@ -440,7 +440,7 @@ class ShowRecordElem
* If no encoding is denoted, it will returns an empty string.
* @return content transfer encoding
*/
- QString getTransferEncoding() const;
+ TQString getTransferEncoding() const;
};
@@ -236,14 +236,14 @@ class ShowRecordElem
* @param filter pointer to the header filter
* @param account name of the account
- * @param mailbox reference to a QString object in which the mailbox name shall be written if the action is MOVE
+ * @param mailbox reference to a TQString object in which the mailbox name shall be written if the action is MOVE
* @param log pointer to the filter log
* @return recommend action